==> openGion8.3.0.4_src.zip: uap/webapps/gf/src/org/opengion/plugin/column/Renderer_QUERY.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.StringFormat;
import org.opengion.fukurou.db.ApplicationInfo;
import org.opengion.fukurou.db.DBUtil;

/**
 * QUERY レンデラーは、表示パラメータで指定された SQL文の実行結果を表示する
 * クラスで、元のValue を、$1 として使用可能です。
 * 又、$Cで自身のカラム名が使用可能です。
 *
 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
 * 変数は、""(ゼロ文字列)として、扱われます。
 * 又、$Cには自分自身のカラム名を割り当てます。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 2.1.1.1 (2002/11/15) QUERY レンデラーを新規追加しました。
 * @og.group データ表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Renderer_QUERY extends AbstractRenderer {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.7.9.0 (2014/08/08)" ;

	private final String query ;
	private final String dbid ;
	private final String name ; // 4.3.4.0 (2008/12/01)

	/** コネクションにアプリケーション情報を追記するかどうか指定 */
	public static final boolean USE_DB_APPLICATION_INFO  = HybsSystem.sysBool( "USE_DB_APPLICATION_INFO" ) ;

	// 3.8.7.0 (2006/12/15) アクセスログ取得の為,ApplicationInfoオブジェクトを設定
	private final ApplicationInfo appInfo;
	private static final String SYSTEM_ID  = HybsSystem.sys( "SYSTEM_ID" ) ;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為,ApplicationInfoオブジェクトを設定
	 *
	 */
	public Renderer_QUERY() {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		query   = null;
		dbid	= null;
		appInfo = makeApplicationInfo( null );
		name	= null; // 4.3.4.0 (2008/12/01)
	}

	/**
	 * DBColumnオブジェクトを指定したprivateコンストラクター。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.4.0.0 (2003/09/01) 表示パラメータ、編集パラメータ、文字パラメータの追加。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為,ApplicationInfoオブジェクトを設定
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Renderer_QUERY( final DBColumn clm ) {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		query = clm.getRendererParam();
		dbid  = clm.getDbid();
		appInfo = makeApplicationInfo( clm.getName() );
		name  = clm.getName();
	}

	/**
	 * アクセスログ取得の為,ApplicationInfoオブジェクトを作成します。
	 *
	 * @og.rev 3.8.7.0 (2006/12/15) 新規作成
	 *
	 * @param	name	オブジェクト
	 *
	 * @return	ApplicationInfoオブジェクト
	 */
	private ApplicationInfo makeApplicationInfo( final String name ) {
		// 6.3.9.1 (2015/11/27) Found 'DD'-anomaly for variable(PMD)
		final ApplicationInfo infoTemp ;

		// 3.8.7.0 (2006/12/15) アクセスログ取得の為,ApplicationInfoオブジェクトを設定
		if( USE_DB_APPLICATION_INFO ) {
			infoTemp = new ApplicationInfo();
			// ユーザーID,IPアドレス,ホスト名
			infoTemp.setClientInfo( SYSTEM_ID,HybsSystem.HOST_ADRS,HybsSystem.HOST_NAME );
			// 画面ID,操作,プログラムID
			infoTemp.setModuleInfo( "Renderer_QUERY",null,name );
		}
		else {
			infoTemp = null;				// 6.3.9.1 (2015/11/27)
		}

		return infoTemp ;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.1.2.1 (2003/04/10) synchronized を、削除します。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 * @og.rtnNotNull
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return new Renderer_QUERY( clm );
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
	 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
	 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
	 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
	 * 変数は、""(ゼロ文字列)として、扱われます。
	 * 又、$Cには自分自身のカラム名を割り当てます。
	 *
	 * @og.rev 3.4.0.2 (2003/09/05) AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てます。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為,ApplicationInfoオブジェクトを設定
	 * @og.rev 4.3.4.0 (2008/12/01) $C対応
	 * @og.rev 5.7.9.0 (2014/08/08) DBUtil.dbExecute 実行時エラーを回避
	 *
	 * @param   value 入力値
	 *
	 * @return  データの表示用文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final String value ) {
		// StringFormat format = new StringFormat( query,value );
		final StringFormat format = new StringFormat( query, value, name ); // 4.3.4.0 (2008/12/01)
		final String str = format.format();

		// 5.7.9.0 (2014/08/08) DBUtil.dbExecute 実行時エラーを回避

		String rtnVal = value == null ? "" : value ;		// 本来、QUERYで変換すべきだが、元の値を設定する。
		try {
			final String[][] rtn = DBUtil.dbExecute( str,null,appInfo,dbid );
			rtnVal = rtn == null || rtn[0] == null || rtn[0][0] == null ? "" : rtn[0][0];			// 6.4.2.1 (2016/02/05) PMD refactoring. Useless parentheses.
		}
		catch( final RuntimeException ex ) {
			final String errMsg = "SQL文の処理に失敗しました。" + CR
								+ "query=" + query + " , inValue=" + value + " , name=" + name
								+ CR
								+ ex.getMessage() ;
			System.err.println( errMsg );
		}

		return rtnVal ;
	}
}

==> openGion8.5.2.0_src.zip: uap/webapps/gf/src/org/opengion/plugin/column/Renderer_QUERY.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.db.AbstractRenderer;
import org.opengion.hayabusa.db.CellRenderer;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.StringFormat;
import org.opengion.fukurou.db.ApplicationInfo;
import org.opengion.fukurou.db.DBUtil;

/**
 * QUERY レンデラーは、表示パラメータで指定された SQL文の実行結果を表示する
 * クラスで、元のValue を、$1 として使用可能です。
 * 又、$Cで自身のカラム名が使用可能です。
 *
 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
 * 変数は、""(ゼロ文字列)として、扱われます。
 * 又、$Cには自分自身のカラム名を割り当てます。
 *
 *  カラムの表示に必要な属性は、DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.rev 2.1.1.1 (2002/11/15) QUERY レンデラーを新規追加しました。
 * @og.group データ表示
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Renderer_QUERY extends AbstractRenderer {
	/** このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "5.7.9.0 (2014/08/08)" ;

	private final String query ;
	private final String dbid ;
	private final String name ; // 4.3.4.0 (2008/12/01)

	/** コネクションにアプリケーション情報を追記するかどうか指定 */
	public static final boolean USE_DB_APPLICATION_INFO  = HybsSystem.sysBool( "USE_DB_APPLICATION_INFO" ) ;

	// 3.8.7.0 (2006/12/15) アクセスログ取得の為、ApplicationInfoオブジェクトを設定
	private final ApplicationInfo appInfo;
	private static final String SYSTEM_ID  = HybsSystem.sys( "SYSTEM_ID" ) ;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為、ApplicationInfoオブジェクトを設定
	 *
	 */
	public Renderer_QUERY() {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		query   = null;
		dbid	= null;
		appInfo = makeApplicationInfo( null );
		name	= null; // 4.3.4.0 (2008/12/01)
	}

	/**
	 * DBColumnオブジェクトを指定したprivateコンストラクター。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.4.0.0 (2003/09/01) 表示パラメータ、編集パラメータ、文字パラメータの追加。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為、ApplicationInfoオブジェクトを設定
	 *
	 * @param	clm	DBColumnオブジェクト
	 */
	private Renderer_QUERY( final DBColumn clm ) {
		super();		// 6.4.1.1 (2016/01/16) PMD refactoring. It is a good practice to call super() in a constructor
		query = clm.getRendererParam();
		dbid  = clm.getDbid();
		appInfo = makeApplicationInfo( clm.getName() );
		name  = clm.getName();
	}

	/**
	 * アクセスログ取得の為、ApplicationInfoオブジェクトを作成します。
	 *
	 * @og.rev 3.8.7.0 (2006/12/15) 新規作成
	 *
	 * @param	name	オブジェクト
	 *
	 * @return	ApplicationInfoオブジェクト
	 */
	private ApplicationInfo makeApplicationInfo( final String name ) {
		// 6.3.9.1 (2015/11/27) Found 'DD'-anomaly for variable(PMD)
		final ApplicationInfo infoTemp ;

		// 3.8.7.0 (2006/12/15) アクセスログ取得の為、ApplicationInfoオブジェクトを設定
		if( USE_DB_APPLICATION_INFO ) {
			infoTemp = new ApplicationInfo();
			// ユーザーID,IPアドレス,ホスト名
			infoTemp.setClientInfo( SYSTEM_ID,HybsSystem.HOST_ADRS,HybsSystem.HOST_NAME );
			// 画面ID,操作,プログラムID
			infoTemp.setModuleInfo( "Renderer_QUERY",null,name );
		}
		else {
			infoTemp = null;				// 6.3.9.1 (2015/11/27)
		}

		return infoTemp ;
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.1.2.1 (2003/04/10) synchronized を、削除します。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return	CellRendererオブジェクト
	 * @og.rtnNotNull
	 */
	public CellRenderer newInstance( final DBColumn clm ) {
		return new Renderer_QUERY( clm );
	}

	/**
	 * データの表示用文字列を返します。
	 *
	 * ここでは、AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てなおして、
	 * QUERYを実行します。また、$1 は、本来の値として、メニューの初期値設定等に
	 * 使用します。上記の例では、AAA が値で、それ以降は、引数になります。
	 * さらに、元の文字列"AAA:BBB:CCC:DDD"は、$0 に割り当てられます。割り当てがない
	 * 変数は、""(ゼロ文字列)として、扱われます。
	 * 又、$Cには自分自身のカラム名を割り当てます。
	 *
	 * @og.rev 3.4.0.2 (2003/09/05) AAA:BBB:CCC:DDD という値を、$1,$2,$3,$4 に割り当てます。
	 * @og.rev 3.8.7.0 (2006/12/15) アクセスログ取得の為、ApplicationInfoオブジェクトを設定
	 * @og.rev 4.3.4.0 (2008/12/01) $C対応
	 * @og.rev 5.7.9.0 (2014/08/08) DBUtil.dbExecute 実行時エラーを回避
	 *
	 * @param   value 入力値
	 *
	 * @return  データの表示用文字列
	 * @og.rtnNotNull
	 */
	@Override
	public String getValue( final String value ) {
		// StringFormat format = new StringFormat( query,value );
		final StringFormat format = new StringFormat( query, value, name ); // 4.3.4.0 (2008/12/01)
		final String str = format.format();

		// 5.7.9.0 (2014/08/08) DBUtil.dbExecute 実行時エラーを回避

		String rtnVal = value == null ? "" : value ;		// 本来、QUERYで変換すべきだが、元の値を設定する。
		try {
			final String[][] rtn = DBUtil.dbExecute( str,null,appInfo,dbid );
			rtnVal = rtn == null || rtn[0] == null || rtn[0][0] == null ? "" : rtn[0][0];			// 6.4.2.1 (2016/02/05) PMD refactoring. Useless parentheses.
		}
		catch( final RuntimeException ex ) {
			final String errMsg = "SQL文の処理に失敗しました。" + CR
								+ "query=" + query + " , inValue=" + value + " , name=" + name
								+ CR
								+ ex.getMessage() ;
			System.err.println( errMsg );
		}

		return rtnVal ;
	}
}
